==> ejc-jlincome-api-3.0.0-20240812.081158-213-sources.jar: com/ejianc/business/jlincome/performance/vo/PersonalGradeViewVO.java <==
package com.ejianc.business.jlincome.performance.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;

/**
 * @author 胡子龙
 * @date 2024/6/18 8:24
 **/
public class PersonalGradeViewVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private String orgName; // 区域名称
    private String employeeName; // 负责人
    private String year; // 年度

    private BigDecimal saleYearTaskMny; // 销售_全年任务
    private BigDecimal saleEndThisMouth; //截止本月完成
    private BigDecimal saleThisMouth; //本月完成

    private BigDecimal kpYearTaskMny; // 开票_全年任务
    private BigDecimal kpEndThisMouth; //截止本月完成
    private BigDecimal kpThisMouth; //本月完成

    private BigDecimal skYearTaskMny; // 开票_全年任务
    private BigDecimal skEndThisMouth; //截止本月完成
    private BigDecimal skThisMouth; //本月完成

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }

    public String getYear() {
        return year;
    }

    public void setYear(String year) {
        this.year = year;
    }

    public BigDecimal getSaleYearTaskMny() {
        return saleYearTaskMny;
    }

    public void setSaleYearTaskMny(BigDecimal saleYearTaskMny) {
        this.saleYearTaskMny = saleYearTaskMny;
    }

    public BigDecimal getSaleEndThisMouth() {
        return saleEndThisMouth;
    }

    public void setSaleEndThisMouth(BigDecimal saleEndThisMouth) {
        this.saleEndThisMouth = saleEndThisMouth;
    }

    public BigDecimal getSaleThisMouth() {
        return saleThisMouth;
    }

    public void setSaleThisMouth(BigDecimal saleThisMouth) {
        this.saleThisMouth = saleThisMouth;
    }

    public BigDecimal getKpYearTaskMny() {
        return kpYearTaskMny;
    }

    public void setKpYearTaskMny(BigDecimal kpYearTaskMny) {
        this.kpYearTaskMny = kpYearTaskMny;
    }

    public BigDecimal getKpEndThisMouth() {
        return kpEndThisMouth;
    }

    public void setKpEndThisMouth(BigDecimal kpEndThisMouth) {
        this.kpEndThisMouth = kpEndThisMouth;
    }

    public BigDecimal getKpThisMouth() {
        return kpThisMouth;
    }

    public void setKpThisMouth(BigDecimal kpThisMouth) {
        this.kpThisMouth = kpThisMouth;
    }

    public BigDecimal getSkYearTaskMny() {
        return skYearTaskMny;
    }

    public void setSkYearTaskMny(BigDecimal skYearTaskMny) {
        this.skYearTaskMny = skYearTaskMny;
    }

    public BigDecimal getSkEndThisMouth() {
        return skEndThisMouth;
    }

    public void setSkEndThisMouth(BigDecimal skEndThisMouth) {
        this.skEndThisMouth = skEndThisMouth;
    }

    public BigDecimal getSkThisMouth() {
        return skThisMouth;
    }

    public void setSkThisMouth(BigDecimal skThisMouth) {
        this.skThisMouth = skThisMouth;
    }


}

==> ejc-jlincome-api-3.0.0-20241114.014431-360-sources.jar: com/ejianc/business/jlincome/performance/vo/PersonalGradeViewVO.java <==
package com.ejianc.business.jlincome.performance.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;

/**
 * @author 胡子龙
 * @date 2024/6/18 8:24
 **/
public class PersonalGradeViewVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private String orgName; // 区域名称
    private String employeeName; // 负责人
    private String year; // 年度

    private BigDecimal saleYearTaskMny; // 销售_全年任务
    private BigDecimal saleEndThisMouth; //截止本月完成
    private BigDecimal saleYearUnComplete; // 本年完成差距
    private BigDecimal saleYearCompleteScale; // 本年完成百分比
    private BigDecimal saleThisMouth; //本月完成

    private BigDecimal kpYearTaskMny; // 开票_全年任务
    private BigDecimal kpEndThisMouth; //截止本月完成
    private BigDecimal kpYearUnComplete; // 本年完成差距
    private BigDecimal kpYearCompleteScale; // 本年完成百分比
    private BigDecimal kpThisMouth; //本月完成

    private BigDecimal skYearTaskMny; // 开票_全年任务
    private BigDecimal skEndThisMouth; //截止本月完成
    private BigDecimal skYearUnComplete; // 本年完成差距
    private BigDecimal skYearCompleteScale; // 本年完成百分比
    private BigDecimal skThisMouth; //本月完成

    public BigDecimal getSaleYearUnComplete() {
        return saleYearUnComplete;
    }

    public void setSaleYearUnComplete(BigDecimal saleYearUnComplete) {
        this.saleYearUnComplete = saleYearUnComplete;
    }

    public BigDecimal getSaleYearCompleteScale() {
        return saleYearCompleteScale;
    }

    public void setSaleYearCompleteScale(BigDecimal saleYearCompleteScale) {
        this.saleYearCompleteScale = saleYearCompleteScale;
    }

    public BigDecimal getKpYearUnComplete() {
        return kpYearUnComplete;
    }

    public void setKpYearUnComplete(BigDecimal kpYearUnComplete) {
        this.kpYearUnComplete = kpYearUnComplete;
    }

    public BigDecimal getKpYearCompleteScale() {
        return kpYearCompleteScale;
    }

    public void setKpYearCompleteScale(BigDecimal kpYearCompleteScale) {
        this.kpYearCompleteScale = kpYearCompleteScale;
    }

    public BigDecimal getSkYearUnComplete() {
        return skYearUnComplete;
    }

    public void setSkYearUnComplete(BigDecimal skYearUnComplete) {
        this.skYearUnComplete = skYearUnComplete;
    }

    public BigDecimal getSkYearCompleteScale() {
        return skYearCompleteScale;
    }

    public void setSkYearCompleteScale(BigDecimal skYearCompleteScale) {
        this.skYearCompleteScale = skYearCompleteScale;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }

    public String getYear() {
        return year;
    }

    public void setYear(String year) {
        this.year = year;
    }

    public BigDecimal getSaleYearTaskMny() {
        return saleYearTaskMny;
    }

    public void setSaleYearTaskMny(BigDecimal saleYearTaskMny) {
        this.saleYearTaskMny = saleYearTaskMny;
    }

    public BigDecimal getSaleEndThisMouth() {
        return saleEndThisMouth;
    }

    public void setSaleEndThisMouth(BigDecimal saleEndThisMouth) {
        this.saleEndThisMouth = saleEndThisMouth;
    }

    public BigDecimal getSaleThisMouth() {
        return saleThisMouth;
    }

    public void setSaleThisMouth(BigDecimal saleThisMouth) {
        this.saleThisMouth = saleThisMouth;
    }

    public BigDecimal getKpYearTaskMny() {
        return kpYearTaskMny;
    }

    public void setKpYearTaskMny(BigDecimal kpYearTaskMny) {
        this.kpYearTaskMny = kpYearTaskMny;
    }

    public BigDecimal getKpEndThisMouth() {
        return kpEndThisMouth;
    }

    public void setKpEndThisMouth(BigDecimal kpEndThisMouth) {
        this.kpEndThisMouth = kpEndThisMouth;
    }

    public BigDecimal getKpThisMouth() {
        return kpThisMouth;
    }

    public void setKpThisMouth(BigDecimal kpThisMouth) {
        this.kpThisMouth = kpThisMouth;
    }

    public BigDecimal getSkYearTaskMny() {
        return skYearTaskMny;
    }

    public void setSkYearTaskMny(BigDecimal skYearTaskMny) {
        this.skYearTaskMny = skYearTaskMny;
    }

    public BigDecimal getSkEndThisMouth() {
        return skEndThisMouth;
    }

    public void setSkEndThisMouth(BigDecimal skEndThisMouth) {
        this.skEndThisMouth = skEndThisMouth;
    }

    public BigDecimal getSkThisMouth() {
        return skThisMouth;
    }

    public void setSkThisMouth(BigDecimal skThisMouth) {
        this.skThisMouth = skThisMouth;
    }


}
